==> nextcloud-15.0.5p1.tgz: nextcloud/apps/survey_client/l10n/nb.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Statistikk for bruksmønster",
    "Last report sent on: {on}" : "Siste rapport sendt: {on}",
    "An error occurred while sending your report." : "Feil under forsendelse av din rapport.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Programliste <em>(for hvert program: navn, versjon, påslått status)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database-miljø <em>(type, versjon, databasestørrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformasjon <em>(er den påskrudd?, hva er forvalgt modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antall ressurser <em>(per type og tilgangsinnstilling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljø <em>(versjon, minnegrense, maksimal eksekveringstid, maksimal filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Tjenerinstallasjonsdetaljer <em>(versjon, bruk av hurtigminne, status for låsing/forhåndsvisninger/avatarer)</em>",
    "Help improve Nextcloud" : "Hjelp til med å forbedre Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe anonymisert data om ditt nåværende oppsett og bruk. Du kan skru det av igjen når som helst fra administrasjonsinnstillingene.",
    "Not now" : "Ikke nå",
    "Send usage" : "Send bruk",
    "Never" : "Aldri",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Sender anonymiserte data til Nextcloud som brukes for å forbedre Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Sender anonymiserte data til Nextcloud som brukes for å forbedre Nextcloud. Du\n        har full kontroll over innhold som sendes Nextcloud og kan deaktivere \n        dette når som helst.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar ditt personvern på alvor. Å sende data er skrudd av som forvalg, ønsker du å sende inn statistikk for bruksmønster blir disse anonymisert først. Du kan velge hva du vil dele. Når du mottar en rapport slettes den forrige. Last opp en tom rapport for å slette alle data som er lagret på tjeneren.",
    "Send new report now" : "Send ny rapport nå",
    "Send usage survey monthly" : "Send statistikk for bruk månedlig ",
    "Data to send" : "Data å sende",
    "Last report sent on: %s" : "Siste rapport sendt: %s",
    "Last report" : "Siste rapport",
    "Sent on: {on}" : "Sendt den: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistikk<em>(antall: filer, brukere, lager per type, kommentarer og merkelapper)</em>",
    "Sent on: %s" : "Sendt den: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/survey_client/l10n/nb.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Siste rapport sendt: {on}",
    "An error occurred while sending your report." : "Feil under forsendelse av din rapport.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Liste over apper <em>(for hver app: navn, versjon, påslått status)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database-miljø <em>(type, versjon, databasestørrelse)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformasjon <em>(er den påskrudd?, hva er forvalgt modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antall ressurser <em>(per type og tilgangsinnstilling)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljø <em>(versjon, minnegrense, maksimal eksekveringstid, maksimal filstørrelse)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstallasjonsdetaljer <em>(versjon, bruk av hurtigminne, status for låsing/forhåndsvisninger/avatarer)</em>",
    "Usage survey" : "Statistikk for bruksmønster",
    "Help improve Nextcloud" : "Hjelp til med å forbedre Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe anonymisert data om ditt nåværende oppsett og bruk. Du kan skru det av igjen når som helst fra administrasjonsinnstillingene.",
    "Not now" : "Ikke nå",
    "Send usage" : "Send bruk",
    "Never" : "Aldri",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Sender anonymiserte data til Nextcloud som brukes for å forbedre Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Sender anonymiserte data til Nextcloud som brukes for å forbedre Nextcloud. Du\n        har full kontroll over innhold som sendes Nextcloud og kan deaktivere \n        dette når som helst.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjelpe til med å forbedre Nextcloud ved å sende oss noe data om ditt nåværende oppsett og bruk.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar ditt personvern på alvor. Å sende data er skrudd av som forvalg, ønsker du å sende inn statistikk for bruksmønster blir disse anonymisert først. Du kan velge hva du vil dele. Når du mottar en rapport slettes den forrige. Last opp en tom rapport for å slette alle data som er lagret på serveren.",
    "Send new report now" : "Send ny rapport nå",
    "Send usage survey monthly" : "Send statistikk for bruk månedlig ",
    "Data to send" : "Data å sende",
    "Last report sent on: %s" : "Siste rapport sendt: %s",
    "Last report" : "Siste rapport"
},
"nplurals=2; plural=(n != 1);");
